@@ -42,13 +42,7 @@ Specified at L<WWW::Search>.
 =head1 AUTHOR and CURRENT VERSION
 
 C<WWW::Search::guru> is written and maintained
-by Glenn Wood, <glenwood@dnai.com>.
-
-The best place to obtain C<WWW::Search::theWorksUSA>
-is from Glenn's releases on CPAN. Because www.theWorksUSA.com
-sometimes changes its format in between his releases, 
-sometimes more up-to-date versions can be found at
-F<http://alumni.caltech.edu/~glenwood/SOFTWARE/index.html>.
+by Glenn Wood, <glenwood@alumni.caltech.edu>.
 
 =head1 COPYRIGHT
 
@@ -68,7 +62,7 @@ require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw(trimTags);
 @ISA = qw(WWW::Search::Scraper Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
 use WWW::Search::Scraper(qw(1.34 generic_option addURL trimTags));
@@ -204,4 +198,13 @@ sub trimLFLFs { # Strip double-LFs, then tag clutter from $_;
     return $self->trimTags($hit, $dat);
 }
 
+
+use WWW::Search::Scraper::Response::Job;
+sub newHit {
+    my $self = new WWW::Search::Scraper::Response::Job;
+    return $self;
+}
+
+
+
 1;
